Stan Math Library: stan/math/prim/mat/fun/squared_distance.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
squared_distance.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_vector.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R1, int C1, int R2, int C2, typename T1 , typename T2 >
boost::math::tools::promote_args< T1, T2 >::type | stan::math::squared_distance (const Eigen::Matrix< T1, R1, C1 > &v1, const Eigen::Matrix< T2, R2, C2 > &v2)
| Returns the squared distance between the specified vectors. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.